/* mf-version.h: version number                         -*- C++ -*-

   Copyright (C) 1996-2020 Christian Schenk

   This file is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published
   by the Free Software Foundation; either version 2, or (at your
   option) any later version.
   
   This file is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this file; if not, write to the Free Software
   Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
   USA.  */

#define MIKTEX_COMP_J2000_VERSION 7439
#define MIKTEX_COMP_ORIG_VERSION_STR "2.718281"

#define MIKTEX_COMP_COPYRIGHT_STR "© 1984 D. E. Knuth"
#define MIKTEX_COMP_TM_STR "METAFONT is a trademark of Addison-Wesley Publishing Company"

#include <miktex/Version>
